Struct poseidon_client::AccountMeta
source · [−]Fields
pubkey: PublicKeyAn account’s public key.
is_signer: boolTrue if an Instruction requires a Transaction signature matching pubkey.
is_writable: boolTrue if the account data or metadata may be mutated during program execution.
Implementations
sourceimpl AccountMeta
impl AccountMeta