Struct poseidon_client::Context
source · [−]Fields
api_version: Stringslot: u64Trait Implementations
sourceimpl BorshDeserialize for Context where
String: BorshDeserialize,
u64: BorshDeserialize,
impl BorshDeserialize for Context where
String: BorshDeserialize,
u64: BorshDeserialize,
sourceimpl BorshSerialize for Context where
String: BorshSerialize,
u64: BorshSerialize,
impl BorshSerialize for Context where
String: BorshSerialize,
u64: BorshSerialize,
sourceimpl<'de> Deserialize<'de> for Context
impl<'de> Deserialize<'de> for Context
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Ord for Context
impl Ord for Context
sourceimpl PartialOrd<Context> for Context
impl PartialOrd<Context> for Context
sourcefn partial_cmp(&self, other: &Context) -> Option<Ordering>
fn partial_cmp(&self, other: &Context) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for Context
impl StructuralEq for Context
impl StructuralPartialEq for Context