Struct poseidon_client::Instruction
source · [−]pub struct Instruction {
pub program_id: PublicKey,
pub accounts: Vec<AccountMeta>,
pub data: Vec<u8>,
}Fields
program_id: PublicKeyPubkey of the program that executes this instruction.
accounts: Vec<AccountMeta>Metadata describing accounts that should be passed to the program.
data: Vec<u8>Opaque data passed to the program for its own interpretation.
Implementations
sourceimpl Instruction
impl Instruction
pub fn new() -> Self
pub fn add_program_id(&mut self, program_id: PublicKey) -> &mut Self
pub fn add_base58_program_id(
&mut self,
program_id: BorrowedBase58PublicKey<'_>
) -> PoseidonResult<&mut Self>
pub fn add_account(&mut self, account_meta: AccountMeta) -> &mut Self
pub fn add_data(&mut self, instruction_data: &[u8]) -> &mut Self
pub fn build(&mut self) -> &mut Self
pub fn borrow(&self) -> &Self
pub fn take(self) -> Self