Struct poseidon_client::JsonRpcError
source · [−]pub struct JsonRpcError { /* private fields */ }Trait Implementations
sourceimpl BorshDeserialize for JsonRpcError where
i16: BorshDeserialize,
String: BorshDeserialize,
impl BorshDeserialize for JsonRpcError where
i16: BorshDeserialize,
String: BorshDeserialize,
sourceimpl BorshSerialize for JsonRpcError where
i16: BorshSerialize,
String: BorshSerialize,
impl BorshSerialize for JsonRpcError where
i16: BorshSerialize,
String: BorshSerialize,
sourceimpl Clone for JsonRpcError
impl Clone for JsonRpcError
sourcefn clone(&self) -> JsonRpcError
fn clone(&self) -> JsonRpcError
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for JsonRpcError
impl Debug for JsonRpcError
sourceimpl<'de> Deserialize<'de> for JsonRpcError
impl<'de> Deserialize<'de> for JsonRpcError
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<JsonRpcError> for JsonRpcError
impl PartialEq<JsonRpcError> for JsonRpcError
sourcefn eq(&self, other: &JsonRpcError) -> bool
fn eq(&self, other: &JsonRpcError) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &JsonRpcError) -> bool
fn ne(&self, other: &JsonRpcError) -> bool
This method tests for !=.
sourceimpl PartialOrd<JsonRpcError> for JsonRpcError
impl PartialOrd<JsonRpcError> for JsonRpcError
sourcefn partial_cmp(&self, other: &JsonRpcError) -> Option<Ordering>
fn partial_cmp(&self, other: &JsonRpcError) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
sourceimpl Serialize for JsonRpcError
impl Serialize for JsonRpcError
impl StructuralPartialEq for JsonRpcError