Struct poseidon_client::RpcInnerInstructions
source · [−]pub struct RpcInnerInstructions {
pub index: u8,
pub instructions: Vec<RpcCompiledInstruction>,
}Fields
index: u8instructions: Vec<RpcCompiledInstruction>Trait Implementations
sourceimpl BorshDeserialize for RpcInnerInstructions where
u8: BorshDeserialize,
Vec<RpcCompiledInstruction>: BorshDeserialize,
impl BorshDeserialize for RpcInnerInstructions where
u8: BorshDeserialize,
Vec<RpcCompiledInstruction>: BorshDeserialize,
sourceimpl BorshSerialize for RpcInnerInstructions where
u8: BorshSerialize,
Vec<RpcCompiledInstruction>: BorshSerialize,
impl BorshSerialize for RpcInnerInstructions where
u8: BorshSerialize,
Vec<RpcCompiledInstruction>: BorshSerialize,
sourceimpl Clone for RpcInnerInstructions
impl Clone for RpcInnerInstructions
sourcefn clone(&self) -> RpcInnerInstructions
fn clone(&self) -> RpcInnerInstructions
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for RpcInnerInstructions
impl Debug for RpcInnerInstructions
sourceimpl<'de> Deserialize<'de> for RpcInnerInstructions
impl<'de> Deserialize<'de> for RpcInnerInstructions
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<RpcInnerInstructions> for RpcInnerInstructions
impl PartialEq<RpcInnerInstructions> for RpcInnerInstructions
sourcefn eq(&self, other: &RpcInnerInstructions) -> bool
fn eq(&self, other: &RpcInnerInstructions) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &RpcInnerInstructions) -> bool
fn ne(&self, other: &RpcInnerInstructions) -> bool
This method tests for !=.
sourceimpl PartialOrd<RpcInnerInstructions> for RpcInnerInstructions
impl PartialOrd<RpcInnerInstructions> for RpcInnerInstructions
sourcefn partial_cmp(&self, other: &RpcInnerInstructions) -> Option<Ordering>
fn partial_cmp(&self, other: &RpcInnerInstructions) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
sourceimpl Serialize for RpcInnerInstructions
impl Serialize for RpcInnerInstructions
impl StructuralPartialEq for RpcInnerInstructions