Struct poseidon_client::RpcResponseJsonError
source · [−]pub struct RpcResponseJsonError { /* private fields */ }Trait Implementations
sourceimpl BorshDeserialize for RpcResponseJsonError where
String: BorshDeserialize,
JsonRpcError: BorshDeserialize,
u8: BorshDeserialize,
impl BorshDeserialize for RpcResponseJsonError where
String: BorshDeserialize,
JsonRpcError: BorshDeserialize,
u8: BorshDeserialize,
sourceimpl BorshSerialize for RpcResponseJsonError where
String: BorshSerialize,
JsonRpcError: BorshSerialize,
u8: BorshSerialize,
impl BorshSerialize for RpcResponseJsonError where
String: BorshSerialize,
JsonRpcError: BorshSerialize,
u8: BorshSerialize,
sourceimpl Clone for RpcResponseJsonError
impl Clone for RpcResponseJsonError
sourcefn clone(&self) -> RpcResponseJsonError
fn clone(&self) -> RpcResponseJsonError
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for RpcResponseJsonError
impl Debug for RpcResponseJsonError
sourceimpl<'de> Deserialize<'de> for RpcResponseJsonError
impl<'de> Deserialize<'de> for RpcResponseJsonError
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<RpcResponseJsonError> for RpcResponseJsonError
impl PartialEq<RpcResponseJsonError> for RpcResponseJsonError
sourcefn eq(&self, other: &RpcResponseJsonError) -> bool
fn eq(&self, other: &RpcResponseJsonError) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &RpcResponseJsonError) -> bool
fn ne(&self, other: &RpcResponseJsonError) -> bool
This method tests for !=.
sourceimpl PartialOrd<RpcResponseJsonError> for RpcResponseJsonError
impl PartialOrd<RpcResponseJsonError> for RpcResponseJsonError
sourcefn partial_cmp(&self, other: &RpcResponseJsonError) -> Option<Ordering>
fn partial_cmp(&self, other: &RpcResponseJsonError) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
sourceimpl Serialize for RpcResponseJsonError
impl Serialize for RpcResponseJsonError
impl StructuralPartialEq for RpcResponseJsonError