Enum poseidon_client::PoseidonError
source · [−]pub enum PoseidonError {
Show 15 variants
Io(ErrorKind),
Http(Minreq),
BincodeError(ErrorKind),
SerdeJsonDeser(String),
MaxSeedLengthExceeded,
IllegalOwner,
UnspecifiedError,
InvalidBase58ForPublicKey,
ErrorConvertingToU832,
ProgramIdNotFound,
PublicKeyNotFoundInMessageAccounts,
AccountIndexNotFoundInMessageAccounts,
Bs58Decode(Error),
Bs58Encode(Error),
TransactionNotFoundInCluster,
}Variants
Io(ErrorKind)
Http(Minreq)
Errors from the minreq crate
BincodeError(ErrorKind)
Errors from the bincode crate
SerdeJsonDeser(String)
Errors encountered when using serde_json crate to deserialize
MaxSeedLengthExceeded
The maximum length of the seed provided has been exceeded
as indicated by [MAX_SEED_LEN]
IllegalOwner
The owner public key of the PDA provided is the same as the
[PDA_MARKER] address. This is not allowed.
UnspecifiedError
The error that occured hasn’t been encountered before
InvalidBase58ForPublicKey
The string provided is not valid for the Base58 format.
ErrorConvertingToU832
Unable to convert a slice to an array of 32 bytes ([u8; 32]).
ProgramIdNotFound
The program ID was not found in the provided instruction
PublicKeyNotFoundInMessageAccounts
The public key was not found in the accounts found in the Message
AccountIndexNotFoundInMessageAccounts
The account index was not found in the Accounts
Bs58Decode(Error)
Error decoding string as Base58 format
Bs58Encode(Error)
Error encoding to base58 format
TransactionNotFoundInCluster
The transaction was not found in the Cluster